<?php

namespace App\Http\Requests;

use App\Http\Requests\Request;
use App\System;

class StationRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
		// look up dialing_length from first system (based on only one system for now)
		$system = System::first();
		$dialing_length = $system->dialing_length;
		
		$input = $this->all();
		
		if(Request::has('create_view') || Request::has('edit_view') ) {
			
			$station_type = $input['type'];

			// special rules for Admin PBX Extension
			if($station_type==3){
				$rules =  [
					'extension' => 'required|regex:/^[0-9]+$/',
					'name' => 'required|max:16|regex:/^[A-Za-z0-9!@$*? .,\-]+$/',
					'description' => 'max:128|regex:/^[A-Za-z0-9!@$*? .,\-]+$/',
					'type' => 'required',
					'facility' => 'required',
					'day_cos' => 'required',
					'night_cos' => 'required',
					'vlan_id' => 'numeric|min:2|max:4094',
					'gateway_port' => 'integer|min:0|max:24',
				];
			} else {
				$rules =  [
					'extension' => 'required|min:'.$dialing_length.'|max:'.$dialing_length.'|regex:/^[0-9]{'.$dialing_length.'}$/',
					'name' => 'required|max:16|regex:/^[A-Za-z0-9!@$*? .,\-]+$/',
					'description' => 'max:128|regex:/^[A-Za-z0-9!@$*? .,\-]+$/',
					'type' => 'required',
					'facility' => 'required',
					'day_cos' => 'required',
					'night_cos' => 'required',
					'vlan_id' => 'numeric|min:2|max:4094',
					'gateway_port' => 'integer|min:0|max:24',
				];
			}		
		} else {
			$rules = [];
		}
		
		return $rules;
    }
	
	public function messages()
	{
    	return [
			'name.regex' => 'Valid name characters include Uppercase letters (A-Z), Lowercase letters (a-z), Digits (0-9), Space, and Special Characters (!@$*?-.,).',
			'description.regex' => 'Valid description characters include Uppercase letters (A-Z), Lowercase letters (a-z), Digits (0-9), Space, and Special Characters (!@$*?-.,).',
    	];
	}
	
	/**
 	* Sanitize input before validation.
 	*
 	* @return array
 	*/
	public function sanitize()
	{
    	$input = $this->all();
		
		if(Request::has('create_view') || Request::has('edit_view') ) {

			//$input['name'] = strip_tags($input['name']);
			//$input['description'] = strip_tags($input['description']);
			$input['station_password'] = strip_tags($input['station_password']);
			$input['station_password_confirmation'] = strip_tags($input['station_password_confirmation']);
			$input['voicemail_password'] = strip_tags($input['voicemail_password']);
			$input['voicemail_password_confirmation'] = strip_tags($input['voicemail_password_confirmation']);
			$input['auth_code'] = strip_tags($input['auth_code']);
			$input['web_username'] = strip_tags($input['web_username']);
			$input['mac_address'] = strtolower($input['mac_address']);
		}
		
    	$this->replace($input);

    	return $this->all();
	}
}
